import mock
import pytest
import resultsdb_api

from resultsdb_listener import senders
from resultsdb_listener import exceptions as exc

class TestResultsdbSender(object):
    def setup_method(self, method):
        self.ref_testcase = 'some.important.test'
        self.ref_status = 'SUCCESS'
        self.ref_url = 'http://127.0.0.1/result/test'
        self.ref_result = {'topic': self.ref_testcase,
                           'status': self.ref_status,
                           'build_url': self.ref_url}

    def test_sender_testcase_exists(self):
        stub_rdb = mock.MagicMock()

        test_sender = senders.ResultsdbSender(stub_rdb)

        test_sender.send(self.ref_result)

        stub_rdb.get_testcase.assert_called_with(self.ref_testcase)

    def test_sender_testcase_exists_failure(self):
        stub_rdb = mock.MagicMock()
        stub_rdb.get_testcase = mock.Mock(side_effect=resultsdb_api.ResultsDBapiException("testcase not found"))

        test_sender = senders.ResultsdbSender(stub_rdb)

        with pytest.raises(exc.SenderError):
            test_sender._check_testcase_exists(self.ref_testcase)

    def test_sender_create_testcase(self):
        stub_rdb = mock.MagicMock()

        test_sender = senders.ResultsdbSender(stub_rdb)

        test_sender._create_testcase(self.ref_testcase)

        stub_rdb.create_testcase.assert_called_with(self.ref_testcase)

    def test_sender_testcase_exists_failure_create(self):
        stub_rdb = mock.MagicMock()
        stub_rdb.get_testcase = mock.Mock(side_effect=resultsdb_api.ResultsDBapiException("testcase not found"))

        test_sender = senders.ResultsdbSender(stub_rdb)

        test_sender.send(self.ref_result)

        stub_rdb.get_testcase.assert_called_with(self.ref_testcase)
        stub_rdb.create_testcase.assert_called_with(self.ref_testcase)

    def test_sender_translate_outcomes(self):
        stub_rdb = mock.MagicMock()

        test_sender = senders.ResultsdbSender(stub_rdb)

        assert test_sender._translate_outcome('SUCCESS') == 'PASSED'
        assert test_sender._translate_outcome('FAILURE') == 'FAILED'
        assert test_sender._translate_outcome('ABORTED') == 'FAILED'

